#!/bin/bash
set -x



COUNTRY=US
STATE=NY
O="International Business Machines Corporation"
OU=SPP

CERT_DIR=/opt/ECX/tools/cert

rm -rf ${CERT_DIR}/{testca,server,client}
mkdir -p ${CERT_DIR}/{testca,server,client}
cd ${CERT_DIR}/testca

mkdir ${CERT_DIR}/testca/{certs,private}
chmod 700  ${CERT_DIR}/testca/private
echo 01 > ${CERT_DIR}/testca/serial
touch ${CERT_DIR}/testca/index.txt

cp ${CERT_DIR}/openssl.cnf  ${CERT_DIR}/testca

openssl req -x509 -config ${CERT_DIR}/testca/openssl.cnf -newkey rsa:2048 -days 365 -out ${CERT_DIR}/testca/cacert.pem -outform PEM -subj "/C=${COUNTRY}/ST=${STATE}/O=${O}/OU=${OU}/CN=$(hostname)" -nodes

openssl x509 -in ${CERT_DIR}/testca/cacert.pem -out ${CERT_DIR}/testca/cacert.cer -outform DER

cd ${CERT_DIR}/server
openssl genrsa -out ${CERT_DIR}/server/key.pem 2048

openssl req -new -key ${CERT_DIR}/server/key.pem -out ${CERT_DIR}/server/req.pem -outform PEM  -subj /CN=$(hostname)/O=server/ -nodes

cd ${CERT_DIR}/testca
openssl ca -config ${CERT_DIR}/testca/openssl.cnf -in ${CERT_DIR}/server/req.pem -out ${CERT_DIR}/server/cert.pem -notext -batch -extensions server_ca_extensions

cd ${CERT_DIR}/server
openssl pkcs12 -export -out ${CERT_DIR}/server/keycert.p12 -in ${CERT_DIR}/server/cert.pem -inkey ${CERT_DIR}/server/key.pem -passout pass:MySecretPassword

cd ${CERT_DIR}/client
openssl genrsa -out ${CERT_DIR}/client/key.pem 2048

openssl req -new -key ${CERT_DIR}/client/key.pem -out ${CERT_DIR}/client/req.pem -outform PEM -subj /CN=$(hostname)/O=client/ -nodes 

cd ${CERT_DIR}/testca
openssl ca -config ${CERT_DIR}/testca/openssl.cnf -in ${CERT_DIR}/client/req.pem -out ${CERT_DIR}/client/cert.pem -notext -batch -extensions client_ca_extensions

cd ${CERT_DIR}/client
openssl pkcs12 -export -out ${CERT_DIR}/client/keycert.p12 -in ${CERT_DIR}/client/cert.pem -inkey ${CERT_DIR}/client/key.pem -passout pass:MySecretPassword
