#!/usr/bin/bash

# Where to write log
LOG="/data/log/firewall.log"

# What firewall action to take
#action=DROP
action=REJECT

# Comma separated list of ports. Each element is either a single number
# or a colon separated range like 443,80:100
# Try to use ranges where possible to keep the list short
tcp="5671,6443,2379:2380,10250:10252,10255,30000:32767"
udp="8472"

(
echo "==> Applying Firewall Rules to Close Sensitive Ports"
/usr/bin/echo -n "=> System started on: "
date

echo "=> Current firewalld setup:"
firewall-cmd --list-all
echo "Direct rules:"
firewall-cmd --direct --get-all-rules
echo
echo "=> Removing existing filter INPUT rules for new replacement rules"
firewall-cmd --permanent --direct --remove-rules ipv4 filter INPUT
firewall-cmd --reload

# Look for interfaces from default zone which should
# omit all docker/k8s interfaces
if=$(firewall-cmd --list-interfaces)

echo "=> Setting new rules for available interfaces: $if"

# For each adapter we find generate the needed rules
for iface in $if
do
 echo "Updating interface: $iface"

 # Apply TCP blocks
 firewall-cmd --permanent --direct --add-rule ipv4 filter INPUT 0 -i $iface -p tcp -m multiport --dports $tcp -j $action

 # Apply UDP blocks
 firewall-cmd --permanent --direct --add-rule ipv4 filter INPUT 0 -i $iface -p udp -m multiport --dports $udp -j $action

done

echo "=> Results:"
firewall-cmd --reload
firewall-cmd --list-all
echo "Direct rules:"
firewall-cmd --direct --get-all-rules
) | tee $LOG
