import sys
from zipfile import ZipFile
from io import BytesIO
import datetime


class VmLogAnalyzer:
    
    def __init__(self, logFile):
        self.logFile = logFile

    @property
    def isSuccessful(self):
        status = False
        if self.logFile.find("backup completed successfully") != -1:
            status = True

        return status

    @property
    def isCancelled(self):
        status = False
        if self.logFile.find("cancel received") != -1: #has been found
            status = True

        return status




def main(argv):
    #unzip log collect
    if(len(argv) < 2 ):
        print("Please specify log collect file")
    else:
        logCollect = argv[1]
        with ZipFile(logCollect, "r") as zip: 
            nl = zip.namelist()
            proxyFileCount = 0
            earliestLog = datetime.datetime.fromtimestamp(2000000000)
            latestLog = datetime.datetime.fromtimestamp(0)
            for item in nl: 
                splitDir = item.split("/")
                if(len(splitDir) >= 2):
                    target = splitDir[1]
                    if target == "vmdkbackupproxy":
                        proxyZip = BytesIO(zip.read(item))
                        with ZipFile(proxyZip) as proxyDir: #traverse zip file for vmdkbackupproxy folder
                            proxyFiles = proxyDir.namelist()
                            for path in proxyFiles:
                                pathList = path.split("/")
                                if(len(pathList) >= 3):
                                    if pathList[2].split(".")[-1] == "log":
                                        with proxyDir.open(path) as f: #open log file for vm
                                            try:
                                                epoch = path.split("/")[1]
                                                logdate = datetime.datetime.fromtimestamp(float(epoch)/1000)
                                                if logdate < earliestLog:
                                                    earliestLog = logdate
                                                if logdate > latestLog:
                                                    latestLog = logdate
                                            except:
                                                print("Error interperting date format: " + epoch)
                                            try:
                                                data = f.read().decode()
                                            except:
                                                print("Error reading file: " + path)
                                                pass
                                            vmName = pathList[2].split(".")[0]
                                            vmLogAnalyzer = VmLogAnalyzer(data)
                                            isCancelled = vmLogAnalyzer.isCancelled
                                            isSuccessful = vmLogAnalyzer.isSuccessful
                                            if(isCancelled and isSuccessful):
                                                print("Incorrect status detected for VM", vmName)
                                        proxyFileCount += 1
        print("Total vadp files processed: " + str(proxyFileCount))
        print("Earliest log: " + str(earliestLog))
        print("Latest log: " + str(latestLog))


    
if __name__ == "__main__":
    main(sys.argv)


