#!/usr/bin/python

import os , shutil, zipfile ,contextlib, re , tempfile , sys
from optparse import OptionParser
from subprocess import call ,Popen, PIPE
import glob


def main():

    dict_manifest = process_jar(options.jar)

    dict_plugin_prop = load_plugin_properties( options.prop )

    rpm = Rpm(dict_plugin_prop,dict_manifest)

    # this will be changed to support multiple bundles/jars
    list = [ rpm.get_name() ]


    if not options.plan :    
        generate_plan_file( rpm.get_name(), list )
    else:
        validate_plan_file()

    rpm.gen_spec_file(SPEC_FILE)

    if (options.mode == 'spec' ): 
        print('The spec file generated in ' + SPEC_FILE + '. You can use it as template for your rpmbuild. ')
        sys.exit(0)

    rpm.rpmbuild(SPEC_FILE)

#-------------------------------------------------------------------------------------
#  validate_options()
#-------------------------------------------------------------------------------------
def validate_options():
    if not options.jar :
        print ("\nPlease provide path to jarfile with '--jar-file' option.\n")
        sys.exit(1)

    if not os.path.exists( options.prop ) :
        print( '\nThe ' + options.prop + ' file does not exist. Please provide path to plugin.properties file with \'--prop=\' option.\n')
        sys.exit(1)

    if not os.path.exists( options.release ) :
        print( '\nThe ' + options.release + ' file does not exist. Please provide path to release.html file with \'--release-file=\' option.\n')
        sys.exit(1)

    if not os.path.exists( options.help ) :
        print( '\nThe ' + options.help + ' file does not exist. Please provide path to help.html file with \'--help-file=\' option.\n')
        sys.exit(1)

    if not os.path.exists( options.icon_small ) :
        print( '\nThe ' + options.icon_small + ' file does not exist. Please provide path to icon_small.png file with \'--icon-small-file=\' option.\n')
        sys.exit(1)

    if not os.path.exists( options.icon_large ) :
        print( '\nThe ' + options.icon_large + ' file does not exist. Please provide path to icon_large.png file with \'--icon-large-file=\' option.\n')
        sys.exit(1)

    if options.screenshot1 is not None :
        if not os.path.exists( options.screenshot1 ) :
            print( '\nThe ' + options.screenshot1 + ' file does not exist. Please provide path to screenshot1.png file with \'--screenshot1-file=\' option.\n')
            sys.exit(1)

    if options.screenshot2 is not None :
        if not os.path.exists( options.screenshot2 ) :
            print( '\nThe ' + options.screenshot2 + ' file does not exist. Please provide path to screenshot2.png file with \'--screenshot2-file=\' option.\n')
            sys.exit(1)

    if options.screenshot3 is not None :
        if not os.path.exists( options.screenshot3 ) :
            print( '\nThe ' + options.screenshot3 + ' file does not exist. Please provide path to screenshot3.png file with \'--screenshot3-file=\' option.\n')
            sys.exit(1)

    if options.screenshot4 is not None :
        if not os.path.exists( options.screenshot4 ) :
            print( '\nThe ' + options.screenshot4 + ' file does not exist. Please provide path to screenshot4.png file with \'--screenshot4-file=\' option.\n')
            sys.exit(1)

    if options.screenshot5 is not None :
        if not os.path.exists( options.screenshot5 ) :
            print( '\nThe ' + options.screenshot5 + ' file does not exist. Please provide path to screenshot5.png file with \'--screenshot5-file=\' option.\n')
            sys.exit(1)

    if not os.path.isabs(options.jar): 
        options.jar=os.path.abspath( os.getcwd() + os.sep + options.jar ) 

    if not os.path.isabs(options.prop): 
        options.prop=os.path.abspath( os.getcwd() + os.sep + options.prop ) 

    if ( os.getuid() == 0 ):
        print ("\nYou can not build rpm as root user. Please change user.\n")
        sys.exit(1)

#-------------------------------------------------------------------------------------
#
#  process_open (cmd)
# This function called with an argument as a list. 
# This is better way to call Popen w/o shell=True. It handles spaces in executable path
#-------------------------------------------------------------------------------------
def process_open (cmd):
    if options.verbosity : print (cmd)

    p = Popen( cmd ,stdout=PIPE, stderr=PIPE )
    stdout, stderr = p.communicate()
    if options.verbosity :
        print (p.returncode)
        print ( stderr ) 

    if not options.verbosity and p.returncode == 0 :  print 'Success'
    if not options.verbosity and p.returncode != 0 :  print 'Failure'
          
    
    return p.returncode

#-------------------------------------------------------------------------------------
#
#  load_jar()
#  returns dictionary created from META-INF/MANIFEST.MF
#-------------------------------------------------------------------------------------
def process_jar(jarfile):

    temp_directory = tempfile.gettempdir() + os.sep + str(os.getpid())

    if options.verbosity : print ( 'temp directory : ' + temp_directory + ', jar: ' + jarfile )

    unzip( jarfile, temp_directory  )

    if not os.path.exists (temp_directory + os.sep + "META-INF/MANIFEST.MF"):
        print ('Jar + ' + jar +  ' does not contain META-INF/MANIFEST.MF" file  ')
        shutil.rmtree(temp_directory)
        sys.exit(2)

    dict = load_manifest(temp_directory + os.sep + "META-INF/MANIFEST.MF")

    if os.path.exists( temp_directory): shutil.rmtree( temp_directory )

    return dict

#-------------------------------------------------------------------------------------
#
#   find_files()
#   draft, will change it to support depth
#-------------------------------------------------------------------------------------
def find_files(temp_directory):
    dir_list = os.listdir(temp_directory)
    
    list = []
    for dir in dir_list:
        if dir != "META-INF" :
            list = os.listdir(temp_directory + os.sep + dir  )
            break;

    return list


#-------------------------------------------------------------------------------------
#
#   unzip()
# 
#-------------------------------------------------------------------------------------
def unzip(source_filename, dest_dir):

    if os.path.exists( dest_dir): shutil.rmtree( dest_dir)
    
    # add jar validation
    with contextlib.closing(zipfile.ZipFile (source_filename, "r")) as z:
        z.extractall(dest_dir)

#-------------------------------------------------------------------------------------
#
#   load_manifest()
#
# loads META-INF/MANIFEST.MF  file 
# returns dictionary
#-------------------------------------------------------------------------------------
def load_manifest(manifest):

    d = {}
    with open(manifest) as f:
        key =''
        value=''
        multi_line_record = False

        for line in f:

            if line.rstrip():
                if not line.startswith("#"):
                    #print( 'debug: ' + line)

                    if not line.startswith(' '):

                        # record last key pair , if dictionary is not empty
                        if d and  multi_line_record : 
                            #print ('record old keypair, ' + key + ':' + value )
                            d[key] = value

                        key, value  = line.split(':',1 )
                        d[key] = value.strip()                        
                        multi_line_record=False

                    else:
                        multi_line_record=True
                        value += line.strip()


    if 0:
        print('------------------------')
        for key in d.keys():
            print (key + ' : ' + d[key] )

    return d 

#-------------------------------------------------------------------------------------
#
#   load_plugin_properties
#
#-------------------------------------------------------------------------------------
def load_plugin_properties(prop):
    d = {}
    with open(prop) as f:
        key =''
        value=''

        for line in f:

            if line.rstrip():
                if not line.startswith("#"):
                    #print( 'debug: ' + line)
                    key, value  = line.split('=',1 )
                    d[key.strip()] = value.strip()               
  
    if 0: # debug
        print('------------------------')
        for key in d.keys(): print (key + ' : ' + d[key] )

    return d

    
#--------------------------------------------------------------------------
# generate_plan_file()
#  gets bundles list to populate plan file
#
#--------------------------------------------------------------------------
def generate_plan_file(plan_name, bundles_list):
    
    
    output = open(PLAN_FILE,'w')
    
    output.write('<?xml version="1.0" encoding="UTF-8"?>' + '\n')
    output.write('<plan name="' + plan_name + '" version="2.1.0" scoped="false" atomic="false"' + '\n')
    output.write('  xmlns="http://www.springsource.org/schema/dm-server/plan"' + '\n')
    output.write('  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"' + '\n')
    output.write('  xsi:schemaLocation="' + '\n')
    output.write('    http://www.springsource.org/schema/dm-server/plan' + '\n')
    output.write('    http://www.springsource.org/schema/dm-server/plan/springsource-dm-server-plan.xsd">' + '\n')

    for bundle in bundles_list:
        output.write('   <artifact type="bundle" name="' + bundle + '"/>' + '\n')

    output.write('</plan>' + '\n')

    output.close()

#-------------------------------------------------------------------------------------
#   validate_plan_file()
#-------------------------------------------------------------------------------------
def validate_plan_file():
    #todo, validate
    plan_file = options.plan

    if not os.path.exists( plan_file ) :
        print( '\nThe ' + plan_file + \
               ' file does not exist. Omit \'--plan-file\'  option, the plan file will be generated.') 
        sys.exit(1)

    print('\nUser plan file ' + plan_file + ' currently in not validated.\n')

#-------------------------------------------------------------------------------------
#
#  class Rpm
#
#-------------------------------------------------------------------------------------

class Rpm:
    'Common base class for Rpm '

    def __init__( self,manifest):

        self.manifest  = manifest

        self.name    = manifest.get('Bundle-Name','')
        
        bundle_version = manifest.get('Bundle-Version')

        m = re.match( r'(\d+).(\d+).(\d+).(\d+)', bundle_version)
        
        if(m):

            #print ('1 :' + m.group(1) + ', 2 :' + m.group(2) + ' ,3 :' + m.group(3) )
            self.version=str(m.group(1)) + '.' + str(m.group(2)) + '.' + str(m.group(3)) 

        else:
            print('Bundle does not have a valid version ' + bundle_version)


        self.release     = '0'
        self.summary     = manifest.get('Bundle-Description','')
        self.group       = 'Applications'
        self.license     = COMPANY_NAME
        self.url         = WEB_SITE
        self.buildArch   = RPM_ARCH
        self.requires    = 'ecx'
        self.packager    = COMPANY_NAME
        self.description = manifest.get('Bundle-Description','')
        self.install_path= options.install_path

        self.interim_path= PRODUCT_ROOT + '/.install/' + self.name  
        self.pickup_path = PRODUCT_ROOT + '/pickup'  

        self.release_file    = options.release
        self.help_file       = options.help
        self.icon_small_file = options.icon_small
        self.icon_large_file = options.icon_large

        if options.screenshot1 is not None:
            self.screenshot1 = options.screenshot1

        if options.screenshot2 is not None:
            self.screenshot2 = options.screenshot2

        if options.screenshot3 is not None:
            self.screenshot3 = options.screenshot3

        if options.screenshot4 is not None:
            self.screenshot4 = options.screenshot4

        if options.screenshot5 is not None:
            self.screenshot5 = options.screenshot5

        bundle_symbolic_name = manifest.get('Bundle-SymbolicName','')
        # if not empty , that means name is different 

    def __init__( self,plugin_prop, manifest):

        self.release_file    = options.release
        self.help_file       = options.help
        self.icon_small_file = options.icon_small
        self.icon_large_file = options.icon_large

        if options.screenshot1 is not None:
            self.screenshot1_file = options.screenshot1

        if options.screenshot2 is not None:
            self.screenshot2_file = options.screenshot2

        if options.screenshot3 is not None:
            self.screenshot3_file = options.screenshot3

        if options.screenshot4 is not None:
            self.screenshot4_file = options.screenshot4

        if options.screenshot5 is not None:
            self.screenshot5_file = options.screenshot5

        if options.verbosity : print('Using ' + options.prop + ' to generate spec file.')

        list_update = []

        self.plugin_prop  = plugin_prop
        self.manifest     = manifest
        invalid_format    = False

        # ------------------Name------------------------------------------------
        self.name = plugin_prop.get('Name','')

        if not self.name:
            if options.verbosity : print('\t\'Name\' key pair is missing in the properties, looking in MANIFEST.MF file')
            self.name = manifest.get('Bundle-Name','')

            list_update.append('Name = ' + self.name)

            if  not self.name:
                print (options.prop + ' does not have mandatory Name key=value')
                invalid_format = True 

        m = re.match( r'(.*\s.*)', self.name)
        if(m):
            print (' Name key pair does not have valid format [ space is not allowed ].')
            invalid_format = True 
        
        if ( len(self.name)> 100 ):
            print (' Name key pair does not have valid format [ max lenght is 100 characters ].')
            invalid_format = True 

        # ------------------Version------------------------------------------------
        self.version = plugin_prop.get('Version','')
        if not self.version: 
            if options.verbosity : print('\t\'Version\' key pair is missing in the properties, looking in MANIFEST.MF file')
            bundle_version = manifest.get('Bundle-Version')
            m = re.match( r'(\d+).(\d+).(\d+).(\d+)', bundle_version)
            if(m):
                #print ('1 :' + m.group(1) + ', 2 :' + m.group(2) + ' ,3 :' + m.group(3) )
                self.version=str(m.group(1)) + '.' + str(m.group(2)) + '.' + str(m.group(3)) 
            else:
                print('Bundle does not have a valid version ' + bundle_version)
                invalid_format = True 

            if  not self.version:
                print (options.prop + ' does not have mandatory Version key=value')

            list_update.append('Version = ' + self.version)


        else: # version found , check format
            m=re.match( r'(\d+).(\d+).(\d+)', self.version)
            if not m:
                print (' Version (' + self.version + ')  key pair does not have valid format [ three groups of digits separated by dot].')
                invalid_format = True 

        # ------------------Release------------------------------------------------            

        # not supported
        self.release     = '0'

        # ------------------Summary------------------------------------------------
        self.summary     = plugin_prop.get('Summary','')
        if not self.summary:
            if options.verbosity : print('\t\'Summary\' key pair is missing in the properties, looking in MANIFEST.MF file')

            self.summary     = manifest.get('Bundle-Description','')
            if  not self.summary:
                print (options.prop + ' does not have mandatory Summary key=value')
                invalid_format = True 
                
            list_update.append('Summary = ' + self.summary)

        # --------------------------------------------------------------------------

        self.group       = 'Applications'
        self.license     = COMPANY_NAME
        self.url         = WEB_SITE
        self.buildArch   = RPM_ARCH
        self.requires    = 'ecx'
        self.packager    = COMPANY_NAME

        # ------------------Description----------------------------------------------
        self.description     = plugin_prop.get('Description','')
        if not self.description:
            if options.verbosity : print('\t\'Description\' key pair is missing in the properties, looking in MANIFEST.MF file')
            self.description    = manifest.get('Bundle-Description','')
            if  not self.description: # optional parameter, if not found use 'summary'
                self.description = self.summary
                print ('Description key/value was not found , using  Summary instead')


            list_update.append('Description = ' + self.description)
        # --------------------------------------------------------------------------

        self.install_path = options.install_path

        bundle_symbolic_name = manifest.get('Bundle-SymbolicName','')
        # if not empty , that means name is different 
    
        self.plugin_properties_mod_path = options.prop + '.mod'

        self.update_plugin_properties(list_update)

        self.interim_path= PRODUCT_ROOT + '/.install/' + self.name  
        self.pickup_path = PRODUCT_ROOT + '/pickup'  



        if  invalid_format : sys.exit(1)


    #--------------------------------------------------------------------------
    # get_name()
    #--------------------------------------------------------------------------
    def get_name(self):
        return self.name 

    #--------------------------------------------------------------------------
    # get_package_name()
    #--------------------------------------------------------------------------
    def get_package_name(self):
        return self.name + '-' + self.version + '-' + self.release + '.' + RPM_ARCH + '.rpm'


    #--------------------------------------------------------------------------
    # 
    # update_plugin_properties()
    #
    #--------------------------------------------------------------------------
    def update_plugin_properties(self,list):

        shutil.copyfile(options.prop, self.plugin_properties_mod_path)

        output = open(self.plugin_properties_mod_path,'a')
        for line in list:
            output.write(line + '\n')
        output.close()

    #--------------------------------------------------------------------------
    # gen_spec_file (file)
    # where file is a path to spec file
    #--------------------------------------------------------------------------
    def gen_spec_file(self,file):

        cwd = os.getcwd()

        spec_file=open( file , 'w')
        
        spec_file.write( 'Name: '    + self.name    + '\n' ) 
        spec_file.write( 'Version: ' + self.version + '\n' ) 
        spec_file.write( 'Release: ' + self.release + '\n' ) 
        spec_file.write( 'Summary: ' + self.summary + '\n' ) 
        spec_file.write( 'Group: '   + self.group   + '\n' ) 
        spec_file.write( 'License: ' + self.license + '\n' ) 
        spec_file.write( 'URL: '     + self.url     + '\n' ) 
        spec_file.write( 'BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)' + '\n' ) 
        spec_file.write( 'BuildArch: ' + self.buildArch  + '\n' )
        spec_file.write( 'Packager: '  + self.packager  + '\n' )
        spec_file.write( '%description'   + '\n' )
        spec_file.write( self.description + '\n' )
        spec_file.write( '\n' )
        spec_file.write( '%prep'    + '\n' )
        spec_file.write( '%build'   + '\n' )
        spec_file.write( '%install' + '\n' )
        spec_file.write( '[ -d ${RPM_BUILD_ROOT} ] && rm -rf ${RPM_BUILD_ROOT}'  + '\n' )
        spec_file.write( '/bin/mkdir -p ${RPM_BUILD_ROOT}/' + self.install_path  + '\n' )
        spec_file.write( '/bin/mkdir -p ${RPM_BUILD_ROOT}/' + self.pickup_path   + '\n' )
        spec_file.write( '/bin/mkdir -p ${RPM_BUILD_ROOT}/' + self.interim_path  + '\n' )

        spec_file.write( '/bin/cp -xv ' + options.jar +  ' ${RPM_BUILD_ROOT}/' + self.install_path + '\n' )

        # plugin.properties
        spec_file.write( '/bin/cp -xv ' + self.plugin_properties_mod_path + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/plugin.properties'  + '\n' )
        
        # <package_name>.plan
        spec_file.write( '/bin/cp -xv ' + PLAN_FILE + \
                         ' ${RPM_BUILD_ROOT}/' + self.pickup_path + '/' + self.name +'.plan'  + '\n' )


        # release.html
        spec_file.write( '/bin/cp -xv ' + self.release_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/release.html'  + '\n' )

        # help.html
        spec_file.write( '/bin/cp -xv ' + self.help_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/help.html'  + '\n' )

        # icon_small_file
        spec_file.write( '/bin/cp -xv ' + self.icon_small_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/icon_small.png'  + '\n' )

        # icon_large_file
        spec_file.write( '/bin/cp -xv ' + self.icon_large_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/icon_large.png'  + '\n' )

        if options.screenshot1 is not None:
            spec_file.write( '/bin/cp -xv ' + self.screenshot1_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/screenshot1.png'  + '\n' )

        if options.screenshot2 is not None:
            spec_file.write( '/bin/cp -xv ' + self.screenshot2_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/screenshot2.png'  + '\n' )

        if options.screenshot3 is not None:
            spec_file.write( '/bin/cp -xv ' + self.screenshot3_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/screenshot3.png'  + '\n' )

        if options.screenshot4 is not None:
            spec_file.write( '/bin/cp -xv ' + self.screenshot4_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/screenshot4.png'  + '\n' )

        if options.screenshot5 is not None:
            spec_file.write( '/bin/cp -xv ' + self.screenshot5_file + \
                         ' ${RPM_BUILD_ROOT}/' + self.interim_path + '/screenshot5.png'  + '\n' )

        spec_file.write( ''  + '\n' )
        spec_file.write( '%files'  + '\n' )
        spec_file.write( '%defattr(-,root,root,-)'  + '\n' )
        spec_file.write( ''  + '\n' )
        spec_file.write( self.install_path + '/' + os.path.basename(options.jar) + '\n' )
        spec_file.write( self.pickup_path  + '/' + self.name +'.plan\n' ) 
        spec_file.write( self.interim_path + '/plugin.properties\n' )
        spec_file.write( self.interim_path + '/release.html\n' )
        spec_file.write( self.interim_path + '/help.html\n' )
        spec_file.write( self.interim_path + '/icon_small.png\n' )
        spec_file.write( self.interim_path + '/icon_large.png\n' )

        if options.screenshot1 is not None:
            spec_file.write( self.interim_path + '/screenshot1.png\n' )

        if options.screenshot2 is not None:
            spec_file.write( self.interim_path + '/screenshot2.png\n' )

        if options.screenshot3 is not None:
            spec_file.write( self.interim_path + '/screenshot3.png\n' )

        if options.screenshot4 is not None:
            spec_file.write( self.interim_path + '/screenshot4.png\n' )

        if options.screenshot5 is not None:
            spec_file.write( self.interim_path + '/screenshot5.png\n' )

        spec_file.close()
        
        # debug
        if options.verbosity :
            print('-' * 10  + ' start of spec file ' + '-' * 80  + '\n')
            with open(file, 'r') as fin:
                print fin.read()
            print('-' * 10  + ' end of spec file ' + '-' * 80  + '\n')
    
    #-----------------------------------------------------------------------------
    #
    #  wrapper to rpmbuild 
    #
    #-----------------------------------------------------------------------------
    def rpmbuild(self,specfile):
        if not os.path.exists( '/usr/bin/rpmbuild' ) :
            print('Can not find /usr/bin/rpmbuild for building rpm')
            sys.exit(1)
            
        cli=['/usr/bin/rpmbuild', '-ba', specfile ]
        error = process_open(cli)
        
        if not error:
            print('RPM location: ' + RPM_LOCATION  + self.get_package_name() )
            os.remove(SPEC_FILE)
            os.remove(PLAN_FILE)
            
                                
        return error
                



if __name__ == "__main__":

    script_path=os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
    script_path_parent=os.path.dirname(script_path)

    if not os.environ.has_key('SCREENSHOTPATH'):
        screenshotpath = script_path
    else:
        screenshotpath = os.environ['SCREENSHOTPATH']

    parser = OptionParser()
    usage = "usage: %prog [options]"
    parser = OptionParser(usage=usage)

    parser.add_option("-v", action="count", dest="verbosity", help="verbose mode")
    
    parser.add_option("--mode",
                      dest='mode',
                      default="build",
                      help="operations: build,spec"
                      "[ default: %default ]" )


    parser.add_option("--jar-file",
                      dest='jar',
                      default=(''),
                      help="jar file path to package"
                      " [ default: %default ]")

    parser.add_option("--prop-file",
                      dest='prop',
                      default=(os.path.dirname(os.path.realpath(__file__)) + os.sep + 'plugin.properties'),
                      help="path to plugin.properties file to package"
                      " [ default: %default ]")

    parser.add_option("--plan-file",
                      dest='plan',
                      default=(''),
                      help="path to plan file to package, generated if empty."
                      " [ default: %default ]")

    parser.add_option("--release-file",
                      dest='release',
                      default=(os.path.dirname(os.path.realpath(__file__)) + os.sep + 'release.html'),
                      help="absolute path to release file release.html to package."
                      " [ default: %default ]")

    parser.add_option("--help-file",
                      dest='help',
                      default=(os.path.dirname(os.path.realpath(__file__)) + os.sep + 'help.html'),
                      help="absolute path to help file help.html to package."
                      " [ default: %default ]")

    parser.add_option("--icon-small-file",
                      dest='icon_small',
                      default=(os.path.dirname(os.path.realpath(__file__)) + os.sep + 'icon_small.png'),
                      help="absolute path to icon  165x150 pixels file icon_small.png to package."
                      " [ default: %default ]")

    parser.add_option("--icon-large-file",
                      dest='icon_large',
                      default=(os.path.dirname(os.path.realpath(__file__)) + os.sep + 'icon_large.png'),
                      help="absolute path to icon  417x300 pixels file icon_large.png to package."
                        " [ default: %default ]")

    parser.add_option("--screenshot1-file",
                        dest='screenshot1',
                        action='store_const',
                        const= (screenshotpath + os.sep + 'screenshot1.png'),
                        help="absolute path to icon 417x300 pixels file screenshot1.png to package."
                            " [ default: %default ]")

    parser.add_option("--screenshot2-file",
                        dest='screenshot2',
                        action='store_const',
                        const=(screenshotpath + os.sep + 'screenshot2.png'),
                        help="absolute path to icon 417x300 pixels file screenshot2.png to package."
                            " [ default: %default ]")

    parser.add_option("--screenshot3-file",
                        dest='screenshot3',
                        action='store_const',
                        const=(screenshotpath + os.sep + 'screenshot3.png'),
                        help="absolute path to icon 417x300 pixels file screenshot3.png to package."
                            " [ default: %default ]")

    parser.add_option("--screenshot4-file",
                        dest='screenshot4',
                        action='store_const',
                        const=(screenshotpath + os.sep + 'screenshot4.png'),
                        help="absolute path to icon 417x300 pixels file screenshot4.png to package."
                            " [ default: %default ]")

    parser.add_option("--screenshot5-file",
                        dest='screenshot5',
                        action='store_const',
                        const=(screenshotpath + os.sep + 'screenshot5.png'),
                        help="absolute path to icon 417x300 pixels file screenshot5.png to package."
                            " [ default: %default ]")

    # the product base directorey is not configurable 
    PRODUCT_ROOT = '/opt/ECX/virgo'

    parser.add_option("--install-path",
                      dest='install_path',
                      default=(PRODUCT_ROOT + '/repository/features'),
                      help="Installation path"
                      " [ default: %default ]")

    (options, args) = parser.parse_args()

    ##########################################################################################
    # 
    # configuration, global variables
    #
    ##########################################################################################
    SPEC_FILE        = tempfile.gettempdir() + '/auto.spec'
    PLAN_FILE        = tempfile.gettempdir() + '/auto.plan'
    RPM_ARCH         = 'noarch'
    RPM_LOCATION     = os.environ.get('HOME','/home/') + '/rpmbuild/RPMS/' + RPM_ARCH + '/'
    COMPANY_NAME     = 'Catalogic Software'
    WEB_SITE         = 'http://www.catalogicsoftware.com'

    validate_options()
    main()
